@@ -1,4 +1,11 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<context>
+    <name>AppItem</name>
+    <message>
+        <source>Move to Trash</source>
+        <translation>Przenieś do kosza</translation>
+    </message>
+</context>
 <context>
     <name>dock::AppItem</name>
     <message>
@@ -45,4 +52,11 @@
         <translation>Zamknij wszystkie</translation>
     </message>
 </context>
+<context>
+    <name>dock::TaskManager</name>
+    <message>
+        <source>%1 files</source>
+        <translation>%1 plików</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
