@@ -33,9 +33,10 @@ Q_SIGNALS:
     void handlerIsDeleted();
 
     // for window info
+    void appidChanged();
     void pidChanged();
     void titleChanged();
-    void isActiveChanged();
+    void stateChanged();
 
 protected:
     void treeland_foreign_toplevel_handle_v1_pid(uint32_t pid) override;
@@ -80,6 +81,7 @@ public:
     bool isActive() override;
     bool shouldSkip() override;
     bool isMinimized() override;
+    bool isFullscreen();
     bool allowClose() override;
     bool isAttention() override;
 
