@@ -6,6 +6,9 @@
 #include "constants.h"
 
 #include <QDebug>
+#include <QDBusMessage>
+#include <QDBusConnection>
+
 #include <DConfig>
 
 namespace docktray {
@@ -68,6 +71,8 @@ TraySortOrderModel::~TraySortOrderModel()
 
 bool TraySortOrderModel::dropToStashTray(const QString &draggedSurfaceId, int dropVisualIndex, bool isBefore)
 {
+    Q_UNUSED(dropVisualIndex)
+    Q_UNUSED(isBefore)
     // Check if the dragged tray surfaceId exists. Reject if not the case
     QList<QStandardItem *> draggedItems = findItems(draggedSurfaceId);
     if (draggedItems.isEmpty()) return false;
@@ -114,6 +119,7 @@ bool TraySortOrderModel::dropToDockTray(const QString &draggedSurfaceId, int dro
     auto deferUpdateVisualIndex = qScopeGuard([this](){updateVisualIndexes();});
     if (m_hiddenIds.contains(draggedSurfaceId)) {
         m_hiddenIds.removeOne(draggedSurfaceId);
+        handlePluginVisibleChanged(draggedSurfaceId, true);
     }
 
     if (dropOnSurfaceId == QLatin1String("internal/action-show-stash")) {
@@ -203,6 +209,7 @@ void TraySortOrderModel::setSurfaceVisible(const QString &surfaceId, bool visibl
             m_hiddenIds.append(surfaceId);
         }
     }
+    handlePluginVisibleChanged(surfaceId, visible);
     updateVisualIndexes();
 }
 
@@ -275,6 +282,7 @@ QString TraySortOrderModel::findSection(const QString &surfaceId, const QString
     ) {
         if (!m_hiddenIds.contains(surfaceId)) {
             m_hiddenIds.append(surfaceId);
+            handlePluginVisibleChanged(surfaceId, false);
         }
     }
 
@@ -388,7 +396,8 @@ void TraySortOrderModel::updateVisualIndexes()
             if (!m_collapsed) {
                 results[0]->setData(currentVisualIndex++, TraySortOrderModel::VisualIndexRole);
             } else {
-                results[0]->setData(currentVisualIndex-1, TraySortOrderModel::VisualIndexRole);
+                // When collapsed, collapsable items should be hidden (visualIndex = -1)
+                results[0]->setData(-1, TraySortOrderModel::VisualIndexRole);
             }
         }
     }
@@ -420,6 +429,7 @@ void TraySortOrderModel::updateVisualIndexes()
     // "internal/action-toggle-quick-settings"
     results = findItems("internal/action-toggle-quick-settings");
     Q_ASSERT(!results.isEmpty());
+    results[0]->setData(SECTION_FIXED, TraySortOrderModel::SectionTypeRole);
     results[0]->setData(currentVisualIndex, TraySortOrderModel::VisualIndexRole);
     currentVisualIndex++;
 
@@ -514,4 +524,47 @@ void TraySortOrderModel::onAvailableSurfacesChanged()
     saveDataToDConfig();
 }
 
+void TraySortOrderModel::handlePluginVisibleChanged(const QString &surfaceId, bool visible)
+{
+    QStringList parts = surfaceId.split("::");
+    if (parts.size() != 2 || parts.at(1).isEmpty()) {
+        qWarning() << "Invalid surfaceId format:" << surfaceId;
+        return;
+    }
+
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "org.deepin.dde.Dock1",
+        "/org/deepin/dde/Dock1",
+        "org.deepin.dde.Dock1",
+        "setItemOnDock"
+    );
+    
+    const QString DockQuickPlugins = "Dock_Quick_Plugins";
+    msg << DockQuickPlugins
+        << parts.last()
+        << visible;
+    
+    QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
+    
+    if (reply.type() == QDBusMessage::ErrorMessage) {
+        qWarning() << "DBus call failed:" << reply.errorMessage();
+    } else {
+        qDebug() << "setItemOnDock call success";
+    }
+}
+
+QModelIndex TraySortOrderModel::getModelIndexByVisualIndex(int visualIndex) const
+{
+    for (int i = 0; i < rowCount(); i++) {
+        QModelIndex index = this->index(i, 0);
+        int itemVisualIndex = data(index, VisualIndexRole).toInt();
+        bool visibility = data(index, VisibilityRole).toBool();
+        
+        if (visibility && itemVisualIndex == visualIndex) {
+            return index;
+        }
+    }
+    return QModelIndex();
+}
+
 }
