@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
 <context>
     <name>notification::BubbleItem</name>
     <message>
@@ -19,4 +17,4 @@
         <translation>%1 minut temu</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
