@@ -5,6 +5,21 @@
         <source>Clear All</source>
         <translation>Išvalyti visus</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +31,14 @@
         <source>Clear All</source>
         <translation>Išvalyti visus</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -38,21 +61,5 @@
         <source>Just now</source>
         <translation>Ką tik</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>prieš %1 min.</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>prieš %1 val.</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Vakar</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
