@@ -1,10 +1,27 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="uk">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Вилучити все</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Згорнути</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Більше</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>Немає нещодавніх сповіщень</translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +33,14 @@
         <source>Clear All</source>
         <translation>Вилучити все</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Згорнути</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Більше</translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +57,18 @@
         <translation>Параметри сповіщень</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation>Вилучити усе</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Щойно</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 хвилин тому</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 годину тому</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 годин тому</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Вчора</translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
