@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>main</name>
     <message>
@@ -28,4 +26,4 @@
         <translation>启用所有界面和窗口特效，体验最佳视觉效果</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
